
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PaintBucket(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-paint-bucket'], 'items': [{'path': {'d': 'm19 11-8-8-8.6 8.6a2 2 0 0 0 0 2.8l5.2 5.2c.8.8 2 .8 2.8 0L19 11Z'}}, {'path': {'d': 'm5 2 5 5'}}, {'path': {'d': 'M2 13h15'}}, {'path': {'d': 'M22 20a2 2 0 1 1-4 0c0-1.6 1.7-2.4 2-4 .3 1.6 2 2.4 2 4Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserMinus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-minus'], 'items': [{'path': {'d': 'M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2'}}, {'circle': {'cx': '9', 'cy': '7', 'r': '4'}}, {'line': {'x1': '22', 'x2': '16', 'y1': '11', 'y2': '11'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PenOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pen-off'], 'items': [{'path': {'d': 'm10 10-6.157 6.162a2 2 0 0 0-.5.833l-1.322 4.36a.5.5 0 0 0 .622.624l4.358-1.323a2 2 0 0 0 .83-.5L14 13.982'}}, {'path': {'d': 'm12.829 7.172 4.359-4.346a1 1 0 1 1 3.986 3.986l-4.353 4.353'}}, {'path': {'d': 'm2 2 20 20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlaskRound(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flask-round'], 'items': [{'path': {'d': 'M10 2v6.292a7 7 0 1 0 4 0V2'}}, {'path': {'d': 'M5 15h14'}}, {'path': {'d': 'M8.5 2h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderLock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-lock'], 'items': [{'rect': {'width': '8', 'height': '5', 'x': '14', 'y': '17', 'rx': '1'}}, {'path': {'d': 'M10 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v2.5'}}, {'path': {'d': 'M20 17v-2a2 2 0 1 0-4 0v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LogOut(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-log-out'], 'items': [{'path': {'d': 'm16 17 5-5-5-5'}}, {'path': {'d': 'M21 12H9'}}, {'path': {'d': 'M9 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Building2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-building-2'], 'items': [{'path': {'d': 'M10 12h4'}}, {'path': {'d': 'M10 8h4'}}, {'path': {'d': 'M14 21v-3a2 2 0 0 0-4 0v3'}}, {'path': {'d': 'M6 10H4a2 2 0 0 0-2 2v7a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2V9a2 2 0 0 0-2-2h-2'}}, {'path': {'d': 'M6 21V5a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Cone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cone'], 'items': [{'path': {'d': 'm20.9 18.55-8-15.98a1 1 0 0 0-1.8 0l-8 15.98'}}, {'ellipse': {'cx': '12', 'cy': '19', 'rx': '9', 'ry': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Heading6(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-heading-6'], 'items': [{'path': {'d': 'M4 12h8'}}, {'path': {'d': 'M4 18V6'}}, {'path': {'d': 'M12 18V6'}}, {'circle': {'cx': '19', 'cy': '16', 'r': '2'}}, {'path': {'d': 'M20 10c-2 2-3 3.5-3 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartNoAxesCombined(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-no-axes-combined'], 'items': [{'path': {'d': 'M12 16v5'}}, {'path': {'d': 'M16 14v7'}}, {'path': {'d': 'M20 10v11'}}, {'path': {'d': 'm22 3-8.646 8.646a.5.5 0 0 1-.708 0L9.354 8.354a.5.5 0 0 0-.707 0L2 15'}}, {'path': {'d': 'M4 18v3'}}, {'path': {'d': 'M8 14v7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArchiveRestore(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-archive-restore'], 'items': [{'rect': {'width': '20', 'height': '5', 'x': '2', 'y': '3', 'rx': '1'}}, {'path': {'d': 'M4 8v11a2 2 0 0 0 2 2h2'}}, {'path': {'d': 'M20 8v11a2 2 0 0 1-2 2h-2'}}, {'path': {'d': 'm9 15 3-3 3 3'}}, {'path': {'d': 'M12 12v9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PilcrowLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pilcrow-left'], 'items': [{'path': {'d': 'M14 3v11'}}, {'path': {'d': 'M14 9h-3a3 3 0 0 1 0-6h9'}}, {'path': {'d': 'M18 3v11'}}, {'path': {'d': 'M22 18H2l4-4'}}, {'path': {'d': 'm6 22-4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartScatter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-scatter'], 'items': [{'circle': {'cx': '7.5', 'cy': '7.5', 'r': '.5', 'fill': 'currentColor'}}, {'circle': {'cx': '18.5', 'cy': '5.5', 'r': '.5', 'fill': 'currentColor'}}, {'circle': {'cx': '11.5', 'cy': '11.5', 'r': '.5', 'fill': 'currentColor'}}, {'circle': {'cx': '7.5', 'cy': '16.5', 'r': '.5', 'fill': 'currentColor'}}, {'circle': {'cx': '17.5', 'cy': '14.5', 'r': '.5', 'fill': 'currentColor'}}, {'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HardDriveUpload(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hard-drive-upload'], 'items': [{'path': {'d': 'm16 6-4-4-4 4'}}, {'path': {'d': 'M12 2v8'}}, {'rect': {'width': '20', 'height': '8', 'x': '2', 'y': '14', 'rx': '2'}}, {'path': {'d': 'M6 18h.01'}}, {'path': {'d': 'M10 18h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleUser(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-user'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'circle': {'cx': '12', 'cy': '10', 'r': '3'}}, {'path': {'d': 'M7 20.662V19a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v1.662'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SkipForward(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-skip-forward'], 'items': [{'path': {'d': 'M21 4v16'}}, {'path': {'d': 'M6.029 4.285A2 2 0 0 0 3 6v12a2 2 0 0 0 3.029 1.715l9.997-5.998a2 2 0 0 0 .003-3.432z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Drum(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-drum'], 'items': [{'path': {'d': 'm2 2 8 8'}}, {'path': {'d': 'm22 2-8 8'}}, {'ellipse': {'cx': '12', 'cy': '9', 'rx': '10', 'ry': '5'}}, {'path': {'d': 'M7 13.4v7.9'}}, {'path': {'d': 'M12 14v8'}}, {'path': {'d': 'M17 13.4v7.9'}}, {'path': {'d': 'M2 9v8a10 5 0 0 0 20 0V9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def HandHelping(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hand-helping'], 'items': [{'path': {'d': 'M11 12h2a2 2 0 1 0 0-4h-3c-.6 0-1.1.2-1.4.6L3 14'}}, {'path': {'d': 'm7 18 1.6-1.4c.3-.4.8-.6 1.4-.6h4c1.1 0 2.1-.4 2.8-1.2l4.6-4.4a2 2 0 0 0-2.75-2.91l-4.2 3.9'}}, {'path': {'d': 'm2 13 6 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChevronUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chevron-up'], 'items': [{'path': {'d': 'm18 15-6-6-6 6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sprout(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sprout'], 'items': [{'path': {'d': 'M14 9.536V7a4 4 0 0 1 4-4h1.5a.5.5 0 0 1 .5.5V5a4 4 0 0 1-4 4 4 4 0 0 0-4 4c0 2 1 3 1 5a5 5 0 0 1-1 3'}}, {'path': {'d': 'M4 9a5 5 0 0 1 8 4 5 5 0 0 1-8-4'}}, {'path': {'d': 'M5 21h14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Hand(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-hand'], 'items': [{'path': {'d': 'M18 11V6a2 2 0 0 0-2-2a2 2 0 0 0-2 2'}}, {'path': {'d': 'M14 10V4a2 2 0 0 0-2-2a2 2 0 0 0-2 2v2'}}, {'path': {'d': 'M10 10.5V6a2 2 0 0 0-2-2a2 2 0 0 0-2 2v8'}}, {'path': {'d': 'M18 8a2 2 0 1 1 4 0v6a8 8 0 0 1-8 8h-2c-2.8 0-4.5-.86-5.99-2.34l-3.6-3.6a2 2 0 0 1 2.83-2.82L7 15'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Dessert(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-dessert'], 'items': [{'path': {'d': 'M10.162 3.167A10 10 0 0 0 2 13a2 2 0 0 0 4 0v-1a2 2 0 0 1 4 0v4a2 2 0 0 0 4 0v-4a2 2 0 0 1 4 0v1a2 2 0 0 0 4-.006 10 10 0 0 0-8.161-9.826'}}, {'path': {'d': 'M20.804 14.869a9 9 0 0 1-17.608 0'}}, {'circle': {'cx': '12', 'cy': '4', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Flame(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flame'], 'items': [{'path': {'d': 'M12 3q1 4 4 6.5t3 5.5a1 1 0 0 1-14 0 5 5 0 0 1 1-3 1 1 0 0 0 5 0c0-2-1.5-3-1.5-5q0-2 2.5-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def EthernetPort(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-ethernet-port'], 'items': [{'path': {'d': 'm15 20 3-3h2a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2h2l3 3z'}}, {'path': {'d': 'M6 8v1'}}, {'path': {'d': 'M10 8v1'}}, {'path': {'d': 'M14 8v1'}}, {'path': {'d': 'M18 8v1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Webhook(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-webhook'], 'items': [{'path': {'d': 'M18 16.98h-5.99c-1.1 0-1.95.94-2.48 1.9A4 4 0 0 1 2 17c.01-.7.2-1.4.57-2'}}, {'path': {'d': 'm6 17 3.13-5.78c.53-.97.1-2.18-.5-3.1a4 4 0 1 1 6.89-4.06'}}, {'path': {'d': 'm12 6 3.13 5.73C15.66 12.7 16.9 13 18 13a4 4 0 0 1 0 8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GlassWater(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-glass-water'], 'items': [{'path': {'d': 'M5.116 4.104A1 1 0 0 1 6.11 3h11.78a1 1 0 0 1 .994 1.105L17.19 20.21A2 2 0 0 1 15.2 22H8.8a2 2 0 0 1-2-1.79z'}}, {'path': {'d': 'M6 12a5 5 0 0 1 6 0 5 5 0 0 0 6 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PcCase(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pc-case'], 'items': [{'rect': {'width': '14', 'height': '20', 'x': '5', 'y': '2', 'rx': '2'}}, {'path': {'d': 'M15 14h.01'}}, {'path': {'d': 'M9 6h6'}}, {'path': {'d': 'M9 10h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Trello(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-trello'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2', 'ry': '2'}}, {'rect': {'width': '3', 'height': '9', 'x': '7', 'y': '7'}}, {'rect': {'width': '3', 'height': '5', 'x': '14', 'y': '7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowDownToDot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-down-to-dot'], 'items': [{'path': {'d': 'M12 2v14'}}, {'path': {'d': 'm19 9-7 7-7-7'}}, {'circle': {'cx': '12', 'cy': '21', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def DraftingCompass(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-drafting-compass'], 'items': [{'path': {'d': 'm12.99 6.74 1.93 3.44'}}, {'path': {'d': 'M19.136 12a10 10 0 0 1-14.271 0'}}, {'path': {'d': 'm21 21-2.16-3.84'}}, {'path': {'d': 'm3 21 8.02-14.26'}}, {'circle': {'cx': '12', 'cy': '5', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClipboardPaste(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clipboard-paste'], 'items': [{'path': {'d': 'M11 14h10'}}, {'path': {'d': 'M16 4h2a2 2 0 0 1 2 2v1.344'}}, {'path': {'d': 'm17 18 4-4-4-4'}}, {'path': {'d': 'M8 4H6a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h12a2 2 0 0 0 1.793-1.113'}}, {'rect': {'x': '8', 'y': '2', 'width': '8', 'height': '4', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TextSearch(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-text-search'], 'items': [{'path': {'d': 'M21 5H3'}}, {'path': {'d': 'M10 12H3'}}, {'path': {'d': 'M10 19H3'}}, {'circle': {'cx': '17', 'cy': '15', 'r': '3'}}, {'path': {'d': 'm21 19-1.9-1.9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowRightToLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-right-to-line'], 'items': [{'path': {'d': 'M17 12H3'}}, {'path': {'d': 'm11 18 6-6-6-6'}}, {'path': {'d': 'M21 5v14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Languages(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-languages'], 'items': [{'path': {'d': 'm5 8 6 6'}}, {'path': {'d': 'm4 14 6-6 2-3'}}, {'path': {'d': 'M2 5h12'}}, {'path': {'d': 'M7 2h1'}}, {'path': {'d': 'm22 22-5-10-5 10'}}, {'path': {'d': 'M14 18h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Castle(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-castle'], 'items': [{'path': {'d': 'M10 5V3'}}, {'path': {'d': 'M14 5V3'}}, {'path': {'d': 'M15 21v-3a3 3 0 0 0-6 0v3'}}, {'path': {'d': 'M18 3v8'}}, {'path': {'d': 'M18 5H6'}}, {'path': {'d': 'M22 11H2'}}, {'path': {'d': 'M22 9v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V9'}}, {'path': {'d': 'M6 3v8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MessageSquareLock(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-message-square-lock'], 'items': [{'path': {'d': 'M22 8.5V5a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v16.286a.71.71 0 0 0 1.212.502l2.202-2.202A2 2 0 0 1 6.828 19H10'}}, {'path': {'d': 'M20 15v-2a2 2 0 0 0-4 0v2'}}, {'rect': {'x': '14', 'y': '15', 'width': '8', 'height': '5', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MoveDiagonal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move-diagonal'], 'items': [{'path': {'d': 'M11 19H5v-6'}}, {'path': {'d': 'M13 5h6v6'}}, {'path': {'d': 'M19 5 5 19'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Twitch(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-twitch'], 'items': [{'path': {'d': 'M21 2H3v16h5v4l4-4h5l4-4V2zm-10 9V7m5 4V7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleFadingArrowUp(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-fading-arrow-up'], 'items': [{'path': {'d': 'M12 2a10 10 0 0 1 7.38 16.75'}}, {'path': {'d': 'm16 12-4-4-4 4'}}, {'path': {'d': 'M12 16V8'}}, {'path': {'d': 'M2.5 8.875a10 10 0 0 0-.5 3'}}, {'path': {'d': 'M2.83 16a10 10 0 0 0 2.43 3.4'}}, {'path': {'d': 'M4.636 5.235a10 10 0 0 1 .891-.857'}}, {'path': {'d': 'M8.644 21.42a10 10 0 0 0 7.631-.38'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowUpNarrowWide(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-up-narrow-wide'], 'items': [{'path': {'d': 'm3 8 4-4 4 4'}}, {'path': {'d': 'M7 4v16'}}, {'path': {'d': 'M11 12h4'}}, {'path': {'d': 'M11 16h7'}}, {'path': {'d': 'M11 20h10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TypeOutline(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-type-outline'], 'items': [{'path': {'d': 'M14 16.5a.5.5 0 0 0 .5.5h.5a2 2 0 0 1 0 4H9a2 2 0 0 1 0-4h.5a.5.5 0 0 0 .5-.5v-9a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5V8a2 2 0 0 1-4 0V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v3a2 2 0 0 1-4 0v-.5a.5.5 0 0 0-.5-.5h-3a.5.5 0 0 0-.5.5Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Redo2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-redo-2'], 'items': [{'path': {'d': 'm15 14 5-5-5-5'}}, {'path': {'d': 'M20 9H9.5A5.5 5.5 0 0 0 4 14.5A5.5 5.5 0 0 0 9.5 20H13'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tablet(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tablet'], 'items': [{'rect': {'width': '16', 'height': '20', 'x': '4', 'y': '2', 'rx': '2', 'ry': '2'}}, {'line': {'x1': '12', 'x2': '12.01', 'y1': '18', 'y2': '18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FlipVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-flip-vertical'], 'items': [{'path': {'d': 'M21 8V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v3'}}, {'path': {'d': 'M21 16v3a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-3'}}, {'path': {'d': 'M4 12H2'}}, {'path': {'d': 'M10 12H8'}}, {'path': {'d': 'M16 12h-2'}}, {'path': {'d': 'M22 12h-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Currency(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-currency'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '8'}}, {'line': {'x1': '3', 'x2': '6', 'y1': '3', 'y2': '6'}}, {'line': {'x1': '21', 'x2': '18', 'y1': '3', 'y2': '6'}}, {'line': {'x1': '3', 'x2': '6', 'y1': '21', 'y2': '18'}}, {'line': {'x1': '21', 'x2': '18', 'y1': '21', 'y2': '18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Download(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-download'], 'items': [{'path': {'d': 'M12 15V3'}}, {'path': {'d': 'M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4'}}, {'path': {'d': 'm7 10 5 5 5-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Parentheses(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-parentheses'], 'items': [{'path': {'d': 'M8 21s-4-3-4-9 4-9 4-9'}}, {'path': {'d': 'M16 3s4 3 4 9-4 9-4 9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ImageMinus(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-image-minus'], 'items': [{'path': {'d': 'M21 9v10a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h7'}}, {'line': {'x1': '16', 'x2': '22', 'y1': '5', 'y2': '5'}}, {'circle': {'cx': '9', 'cy': '9', 'r': '2'}}, {'path': {'d': 'm21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Voicemail(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-voicemail'], 'items': [{'circle': {'cx': '6', 'cy': '12', 'r': '4'}}, {'circle': {'cx': '18', 'cy': '12', 'r': '4'}}, {'line': {'x1': '6', 'x2': '18', 'y1': '16', 'y2': '16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TrainFront(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-train-front'], 'items': [{'path': {'d': 'M8 3.1V7a4 4 0 0 0 8 0V3.1'}}, {'path': {'d': 'm9 15-1-1'}}, {'path': {'d': 'm15 15 1-1'}}, {'path': {'d': 'M9 19c-2.8 0-5-2.2-5-5v-4a8 8 0 0 1 16 0v4c0 2.8-2.2 5-5 5Z'}}, {'path': {'d': 'm8 19-2 3'}}, {'path': {'d': 'm16 19 2 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Play(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-play'], 'items': [{'path': {'d': 'M5 5a2 2 0 0 1 3.008-1.728l11.997 6.998a2 2 0 0 1 .003 3.458l-12 7A2 2 0 0 1 5 19z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def WalletMinimal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wallet-minimal'], 'items': [{'path': {'d': 'M17 14h.01'}}, {'path': {'d': 'M7 7h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Instagram(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-instagram'], 'items': [{'rect': {'width': '20', 'height': '20', 'x': '2', 'y': '2', 'rx': '5', 'ry': '5'}}, {'path': {'d': 'M16 11.37A4 4 0 1 1 12.63 8 4 4 0 0 1 16 11.37z'}}, {'line': {'x1': '17.5', 'x2': '17.51', 'y1': '6.5', 'y2': '6.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def List(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list'], 'items': [{'path': {'d': 'M3 5h.01'}}, {'path': {'d': 'M3 12h.01'}}, {'path': {'d': 'M3 19h.01'}}, {'path': {'d': 'M8 5h13'}}, {'path': {'d': 'M8 12h13'}}, {'path': {'d': 'M8 19h13'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CreditCard(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-credit-card'], 'items': [{'rect': {'width': '20', 'height': '14', 'x': '2', 'y': '5', 'rx': '2'}}, {'line': {'x1': '2', 'x2': '22', 'y1': '10', 'y2': '10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Inbox(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-inbox'], 'items': [{'polyline': {'points': '22 12 16 12 14 15 10 15 8 12 2 12'}}, {'path': {'d': 'M5.45 5.11 2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CircleOff(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-circle-off'], 'items': [{'path': {'d': 'm2 2 20 20'}}, {'path': {'d': 'M8.35 2.69A10 10 0 0 1 21.3 15.65'}}, {'path': {'d': 'M19.08 19.08A10 10 0 1 1 4.92 4.92'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Factory(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-factory'], 'items': [{'path': {'d': 'M12 16h.01'}}, {'path': {'d': 'M16 16h.01'}}, {'path': {'d': 'M3 19a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V8.5a.5.5 0 0 0-.769-.422l-4.462 2.844A.5.5 0 0 1 15 10.5v-2a.5.5 0 0 0-.769-.422L9.77 10.922A.5.5 0 0 1 9 10.5V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2z'}}, {'path': {'d': 'M8 16h.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CornerLeftDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-corner-left-down'], 'items': [{'path': {'d': 'm14 15-5 5-5-5'}}, {'path': {'d': 'M20 4h-7a4 4 0 0 0-4 4v12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Undo(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-undo'], 'items': [{'path': {'d': 'M3 7v6h6'}}, {'path': {'d': 'M21 17a9 9 0 0 0-9-9 9 9 0 0 0-6 2.3L3 13'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Section(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-section'], 'items': [{'path': {'d': 'M16 5a4 3 0 0 0-8 0c0 4 8 3 8 7a4 3 0 0 1-8 0'}}, {'path': {'d': 'M8 19a4 3 0 0 0 8 0c0-4-8-3-8-7a4 3 0 0 1 8 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Move(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-move'], 'items': [{'path': {'d': 'M12 2v20'}}, {'path': {'d': 'm15 19-3 3-3-3'}}, {'path': {'d': 'm19 9 3 3-3 3'}}, {'path': {'d': 'M2 12h20'}}, {'path': {'d': 'm5 9-3 3 3 3'}}, {'path': {'d': 'm9 5 3-3 3 3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ReceiptIndianRupee(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-receipt-indian-rupee'], 'items': [{'path': {'d': 'M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z'}}, {'path': {'d': 'M8 7h8'}}, {'path': {'d': 'M12 17.5 8 15h1a4 4 0 0 0 0-8'}}, {'path': {'d': 'M8 11h8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Egg(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-egg'], 'items': [{'path': {'d': 'M12 2C8 2 4 8 4 14a8 8 0 0 0 16 0c0-6-4-12-8-12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FolderDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folder-down'], 'items': [{'path': {'d': 'M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z'}}, {'path': {'d': 'M12 10v6'}}, {'path': {'d': 'm15 13-3 3-3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sword(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sword'], 'items': [{'path': {'d': 'm11 19-6-6'}}, {'path': {'d': 'm5 21-2-2'}}, {'path': {'d': 'm8 16-4 4'}}, {'path': {'d': 'M9.5 17.5 21 6V3h-3L6.5 14.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ParkingMeter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-parking-meter'], 'items': [{'path': {'d': 'M11 15h2'}}, {'path': {'d': 'M12 12v3'}}, {'path': {'d': 'M12 19v3'}}, {'path': {'d': 'M15.282 19a1 1 0 0 0 .948-.68l2.37-6.988a7 7 0 1 0-13.2 0l2.37 6.988a1 1 0 0 0 .948.68z'}}, {'path': {'d': 'M9 9a3 3 0 1 1 6 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Truck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-truck'], 'items': [{'path': {'d': 'M14 18V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v11a1 1 0 0 0 1 1h2'}}, {'path': {'d': 'M15 18H9'}}, {'path': {'d': 'M19 18h2a1 1 0 0 0 1-1v-3.65a1 1 0 0 0-.22-.624l-3.48-4.35A1 1 0 0 0 17.52 8H14'}}, {'circle': {'cx': '17', 'cy': '18', 'r': '2'}}, {'circle': {'cx': '7', 'cy': '18', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ListCollapse(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-list-collapse'], 'items': [{'path': {'d': 'M10 5h11'}}, {'path': {'d': 'M10 12h11'}}, {'path': {'d': 'M10 19h11'}}, {'path': {'d': 'm3 10 3-3-3-3'}}, {'path': {'d': 'm3 20 3-3-3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Squirrel(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-squirrel'], 'items': [{'path': {'d': 'M15.236 22a3 3 0 0 0-2.2-5'}}, {'path': {'d': 'M16 20a3 3 0 0 1 3-3h1a2 2 0 0 0 2-2v-2a4 4 0 0 0-4-4V4'}}, {'path': {'d': 'M18 13h.01'}}, {'path': {'d': 'M18 6a4 4 0 0 0-4 4 7 7 0 0 0-7 7c0-5 4-5 4-10.5a4.5 4.5 0 1 0-9 0 2.5 2.5 0 0 0 5 0C7 10 3 11 3 17c0 2.8 2.2 5 5 5h10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CornerRightDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-corner-right-down'], 'items': [{'path': {'d': 'm10 15 5 5 5-5'}}, {'path': {'d': 'M4 4h7a4 4 0 0 1 4 4v12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LandPlot(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-land-plot'], 'items': [{'path': {'d': 'm12 8 6-3-6-3v10'}}, {'path': {'d': 'm8 11.99-5.5 3.14a1 1 0 0 0 0 1.74l8.5 4.86a2 2 0 0 0 2 0l8.5-4.86a1 1 0 0 0 0-1.74L16 12'}}, {'path': {'d': 'm6.49 12.85 11.02 6.3'}}, {'path': {'d': 'M17.51 12.85 6.5 19.15'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def RotateCwSquare(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-rotate-cw-square'], 'items': [{'path': {'d': 'M12 5H6a2 2 0 0 0-2 2v3'}}, {'path': {'d': 'm9 8 3-3-3-3'}}, {'path': {'d': 'M4 14v4a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TrendingUpDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-trending-up-down'], 'items': [{'path': {'d': 'M14.828 14.828 21 21'}}, {'path': {'d': 'M21 16v5h-5'}}, {'path': {'d': 'm21 3-9 9-4-4-6 6'}}, {'path': {'d': 'M21 8V3h-5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CloudCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-cloud-check'], 'items': [{'path': {'d': 'm17 15-5.5 5.5L9 18'}}, {'path': {'d': 'M5 17.743A7 7 0 1 1 15.71 10h1.79a4.5 4.5 0 0 1 1.5 8.742'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CaseLower(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-case-lower'], 'items': [{'path': {'d': 'M10 9v7'}}, {'path': {'d': 'M14 6v10'}}, {'circle': {'cx': '17.5', 'cy': '12.5', 'r': '3.5'}}, {'circle': {'cx': '6.5', 'cy': '12.5', 'r': '3.5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Table2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-table-2'], 'items': [{'path': {'d': 'M9 3H5a2 2 0 0 0-2 2v4m6-6h10a2 2 0 0 1 2 2v4M9 3v18m0 0h10a2 2 0 0 0 2-2V9M9 21H5a2 2 0 0 1-2-2V9m0 0h18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Link2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-link-2'], 'items': [{'path': {'d': 'M9 17H7A5 5 0 0 1 7 7h2'}}, {'path': {'d': 'M15 7h2a5 5 0 1 1 0 10h-2'}}, {'line': {'x1': '8', 'x2': '16', 'y1': '12', 'y2': '12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Link(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-link'], 'items': [{'path': {'d': 'M10 13a5 5 0 0 0 7.54.54l3-3a5 5 0 0 0-7.07-7.07l-1.72 1.71'}}, {'path': {'d': 'M14 11a5 5 0 0 0-7.54-.54l-3 3a5 5 0 0 0 7.07 7.07l1.71-1.71'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TrainTrack(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-train-track'], 'items': [{'path': {'d': 'M2 17 17 2'}}, {'path': {'d': 'm2 14 8 8'}}, {'path': {'d': 'm5 11 8 8'}}, {'path': {'d': 'm8 8 8 8'}}, {'path': {'d': 'm11 5 8 8'}}, {'path': {'d': 'm14 2 8 8'}}, {'path': {'d': 'M7 22 22 7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tangent(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tangent'], 'items': [{'circle': {'cx': '17', 'cy': '4', 'r': '2'}}, {'path': {'d': 'M15.59 5.41 5.41 15.59'}}, {'circle': {'cx': '4', 'cy': '17', 'r': '2'}}, {'path': {'d': 'M12 22s-4-9-1.5-11.5S22 12 22 12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SlidersVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sliders-vertical'], 'items': [{'path': {'d': 'M10 8h4'}}, {'path': {'d': 'M12 21v-9'}}, {'path': {'d': 'M12 8V3'}}, {'path': {'d': 'M17 16h4'}}, {'path': {'d': 'M19 12V3'}}, {'path': {'d': 'M19 21v-5'}}, {'path': {'d': 'M3 14h4'}}, {'path': {'d': 'M5 10V3'}}, {'path': {'d': 'M5 21v-7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MonitorPause(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-monitor-pause'], 'items': [{'path': {'d': 'M10 13V7'}}, {'path': {'d': 'M14 13V7'}}, {'rect': {'width': '20', 'height': '14', 'x': '2', 'y': '3', 'rx': '2'}}, {'path': {'d': 'M12 17v4'}}, {'path': {'d': 'M8 21h8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Quote(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-quote'], 'items': [{'path': {'d': 'M16 3a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2 1 1 0 0 1 1 1v1a2 2 0 0 1-2 2 1 1 0 0 0-1 1v2a1 1 0 0 0 1 1 6 6 0 0 0 6-6V5a2 2 0 0 0-2-2z'}}, {'path': {'d': 'M5 3a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2 1 1 0 0 1 1 1v1a2 2 0 0 1-2 2 1 1 0 0 0-1 1v2a1 1 0 0 0 1 1 6 6 0 0 0 6-6V5a2 2 0 0 0-2-2z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartSpline(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-spline'], 'items': [{'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}, {'path': {'d': 'M7 16c.5-2 1.5-7 4-7 2 0 2 3 4 3 2.5 0 4.5-5 5-7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Sofa(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-sofa'], 'items': [{'path': {'d': 'M20 9V6a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v3'}}, {'path': {'d': 'M2 16a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-5a2 2 0 0 0-4 0v1.5a.5.5 0 0 1-.5.5h-11a.5.5 0 0 1-.5-.5V11a2 2 0 0 0-4 0z'}}, {'path': {'d': 'M4 18v2'}}, {'path': {'d': 'M20 18v2'}}, {'path': {'d': 'M12 4v9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Vegan(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-vegan'], 'items': [{'path': {'d': 'M16 8q6 0 6-6-6 0-6 6'}}, {'path': {'d': 'M17.41 3.59a10 10 0 1 0 3 3'}}, {'path': {'d': 'M2 2a26.6 26.6 0 0 1 10 20c.9-6.82 1.5-9.5 4-14'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TrendingDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-trending-down'], 'items': [{'path': {'d': 'M16 17h6v-6'}}, {'path': {'d': 'm22 17-8.5-8.5-5 5L2 7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Bone(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-bone'], 'items': [{'path': {'d': 'M17 10c.7-.7 1.69 0 2.5 0a2.5 2.5 0 1 0 0-5 .5.5 0 0 1-.5-.5 2.5 2.5 0 1 0-5 0c0 .81.7 1.8 0 2.5l-7 7c-.7.7-1.69 0-2.5 0a2.5 2.5 0 0 0 0 5c.28 0 .5.22.5.5a2.5 2.5 0 1 0 5 0c0-.81-.7-1.8 0-2.5Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Route(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-route'], 'items': [{'circle': {'cx': '6', 'cy': '19', 'r': '3'}}, {'path': {'d': 'M9 19h8.5a3.5 3.5 0 0 0 0-7h-11a3.5 3.5 0 0 1 0-7H15'}}, {'circle': {'cx': '18', 'cy': '5', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TowerControl(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tower-control'], 'items': [{'path': {'d': 'M18.2 12.27 20 6H4l1.8 6.27a1 1 0 0 0 .95.73h10.5a1 1 0 0 0 .96-.73Z'}}, {'path': {'d': 'M8 13v9'}}, {'path': {'d': 'M16 22v-9'}}, {'path': {'d': 'm9 6 1 7'}}, {'path': {'d': 'm15 6-1 7'}}, {'path': {'d': 'M12 6V2'}}, {'path': {'d': 'M13 2h-2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CardSim(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-card-sim'], 'items': [{'path': {'d': 'M12 14v4'}}, {'path': {'d': 'M14.172 2a2 2 0 0 1 1.414.586l3.828 3.828A2 2 0 0 1 20 7.828V20a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2z'}}, {'path': {'d': 'M8 14h8'}}, {'rect': {'x': '8', 'y': '10', 'width': '8', 'height': '8', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BatteryWarning(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-battery-warning'], 'items': [{'path': {'d': 'M10 17h.01'}}, {'path': {'d': 'M10 7v6'}}, {'path': {'d': 'M14 6h2a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2'}}, {'path': {'d': 'M22 14v-4'}}, {'path': {'d': 'M6 18H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Piano(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-piano'], 'items': [{'path': {'d': 'M18.5 8c-1.4 0-2.6-.8-3.2-2A6.87 6.87 0 0 0 2 9v11a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-8.5C22 9.6 20.4 8 18.5 8'}}, {'path': {'d': 'M2 14h20'}}, {'path': {'d': 'M6 14v4'}}, {'path': {'d': 'M10 14v4'}}, {'path': {'d': 'M14 14v4'}}, {'path': {'d': 'M18 14v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Diameter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-diameter'], 'items': [{'circle': {'cx': '19', 'cy': '19', 'r': '2'}}, {'circle': {'cx': '5', 'cy': '5', 'r': '2'}}, {'path': {'d': 'M6.48 3.66a10 10 0 0 1 13.86 13.86'}}, {'path': {'d': 'm6.41 6.41 11.18 11.18'}}, {'path': {'d': 'M3.66 6.48a10 10 0 0 0 13.86 13.86'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def TestTubeDiagonal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-test-tube-diagonal'], 'items': [{'path': {'d': 'M21 7 6.82 21.18a2.83 2.83 0 0 1-3.99-.01a2.83 2.83 0 0 1 0-4L17 3'}}, {'path': {'d': 'm16 2 6 6'}}, {'path': {'d': 'M12 16H4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Milk(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-milk'], 'items': [{'path': {'d': 'M8 2h8'}}, {'path': {'d': 'M9 2v2.789a4 4 0 0 1-.672 2.219l-.656.984A4 4 0 0 0 7 10.212V20a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-9.789a4 4 0 0 0-.672-2.219l-.656-.984A4 4 0 0 1 15 4.788V2'}}, {'path': {'d': 'M7 15a6.472 6.472 0 0 1 5 0 6.47 6.47 0 0 0 5 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Motorbike(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-motorbike'], 'items': [{'path': {'d': 'm18 14-1-3'}}, {'path': {'d': 'm3 9 6 2a2 2 0 0 1 2-2h2a2 2 0 0 1 1.99 1.81'}}, {'path': {'d': 'M8 17h3a1 1 0 0 0 1-1 6 6 0 0 1 6-6 1 1 0 0 0 1-1v-.75A5 5 0 0 0 17 5'}}, {'circle': {'cx': '19', 'cy': '17', 'r': '3'}}, {'circle': {'cx': '5', 'cy': '17', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ShowerHead(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-shower-head'], 'items': [{'path': {'d': 'm4 4 2.5 2.5'}}, {'path': {'d': 'M13.5 6.5a4.95 4.95 0 0 0-7 7'}}, {'path': {'d': 'M15 5 5 15'}}, {'path': {'d': 'M14 17v.01'}}, {'path': {'d': 'M10 16v.01'}}, {'path': {'d': 'M13 13v.01'}}, {'path': {'d': 'M16 10v.01'}}, {'path': {'d': 'M11 20v.01'}}, {'path': {'d': 'M17 14v.01'}}, {'path': {'d': 'M20 11v.01'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileX(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-x'], 'items': [{'path': {'d': 'M6 22a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.704.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2z'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'm14.5 12.5-5 5'}}, {'path': {'d': 'm9.5 12.5 5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Facebook(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-facebook'], 'items': [{'path': {'d': 'M18 2h-3a5 5 0 0 0-5 5v3H7v4h3v8h4v-8h3l1-4h-4V7a1 1 0 0 1 1-1h3z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PilcrowRight(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pilcrow-right'], 'items': [{'path': {'d': 'M10 3v11'}}, {'path': {'d': 'M10 9H7a1 1 0 0 1 0-6h8'}}, {'path': {'d': 'M14 3v11'}}, {'path': {'d': 'm18 14 4 4H2'}}, {'path': {'d': 'm22 18-4 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PersonStanding(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-person-standing'], 'items': [{'circle': {'cx': '12', 'cy': '5', 'r': '1'}}, {'path': {'d': 'm9 20 3-6 3 6'}}, {'path': {'d': 'm6 8 6 2 6-2'}}, {'path': {'d': 'M12 10v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def PenLine(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-pen-line'], 'items': [{'path': {'d': 'M13 21h8'}}, {'path': {'d': 'M21.174 6.812a1 1 0 0 0-3.986-3.987L3.842 16.174a2 2 0 0 0-.5.83l-1.321 4.352a.5.5 0 0 0 .623.622l4.353-1.32a2 2 0 0 0 .83-.497z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Folders(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-folders'], 'items': [{'path': {'d': 'M20 5a2 2 0 0 1 2 2v7a2 2 0 0 1-2 2H9a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h2.5a1.5 1.5 0 0 1 1.2.6l.6.8a1.5 1.5 0 0 0 1.2.6z'}}, {'path': {'d': 'M3 8.268a2 2 0 0 0-1 1.738V19a2 2 0 0 0 2 2h11a2 2 0 0 0 1.732-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AppWindow(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-app-window'], 'items': [{'rect': {'x': '2', 'y': '4', 'width': '20', 'height': '16', 'rx': '2'}}, {'path': {'d': 'M10 4v4'}}, {'path': {'d': 'M2 8h20'}}, {'path': {'d': 'M6 4v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ArrowBigRightDash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-arrow-big-right-dash'], 'items': [{'path': {'d': 'M11 9a1 1 0 0 0 1-1V5.061a1 1 0 0 1 1.811-.75l6.836 6.836a1.207 1.207 0 0 1 0 1.707l-6.836 6.835a1 1 0 0 1-1.811-.75V16a1 1 0 0 0-1-1H9a1 1 0 0 1-1-1v-4a1 1 0 0 1 1-1z'}}, {'path': {'d': 'M4 9v6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Maximize2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-maximize-2'], 'items': [{'path': {'d': 'M15 3h6v6'}}, {'path': {'d': 'm21 3-7 7'}}, {'path': {'d': 'm3 21 7-7'}}, {'path': {'d': 'M9 21H3v-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def MapPinCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-map-pin-check'], 'items': [{'path': {'d': 'M19.43 12.935c.357-.967.57-1.955.57-2.935a8 8 0 0 0-16 0c0 4.993 5.539 10.193 7.399 11.799a1 1 0 0 0 1.202 0 32.197 32.197 0 0 0 .813-.728'}}, {'circle': {'cx': '12', 'cy': '10', 'r': '3'}}, {'path': {'d': 'm16 18 2 2 4-4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Gavel(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-gavel'], 'items': [{'path': {'d': 'm14 13-8.381 8.38a1 1 0 0 1-3.001-3l8.384-8.381'}}, {'path': {'d': 'm16 16 6-6'}}, {'path': {'d': 'm21.5 10.5-8-8'}}, {'path': {'d': 'm8 8 6-6'}}, {'path': {'d': 'm8.5 7.5 8 8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Caravan(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-caravan'], 'items': [{'path': {'d': 'M18 19V9a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v8a2 2 0 0 0 2 2h2'}}, {'path': {'d': 'M2 9h3a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1H2'}}, {'path': {'d': 'M22 17v1a1 1 0 0 1-1 1H10v-9a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v9'}}, {'circle': {'cx': '8', 'cy': '19', 'r': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Navigation2Off(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-navigation-2-off'], 'items': [{'path': {'d': 'M9.31 9.31 5 21l7-4 7 4-1.17-3.17'}}, {'path': {'d': 'M14.53 8.88 12 2l-1.17 3.17'}}, {'line': {'x1': '2', 'x2': '22', 'y1': '2', 'y2': '22'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Lectern(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-lectern'], 'items': [{'path': {'d': 'M16 12h3a2 2 0 0 0 1.902-1.38l1.056-3.333A1 1 0 0 0 21 6H3a1 1 0 0 0-.958 1.287l1.056 3.334A2 2 0 0 0 5 12h3'}}, {'path': {'d': 'M18 6V3a1 1 0 0 0-1-1h-3'}}, {'rect': {'width': '8', 'height': '12', 'x': '8', 'y': '10', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Music4(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-music-4'], 'items': [{'path': {'d': 'M9 18V5l12-2v13'}}, {'path': {'d': 'm9 9 12-2'}}, {'circle': {'cx': '6', 'cy': '18', 'r': '3'}}, {'circle': {'cx': '18', 'cy': '16', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Highlighter(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-highlighter'], 'items': [{'path': {'d': 'm9 11-6 6v3h9l3-3'}}, {'path': {'d': 'm22 12-4.6 4.6a2 2 0 0 1-2.8 0l-5.2-5.2a2 2 0 0 1 0-2.8L14 4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Replace(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-replace'], 'items': [{'path': {'d': 'M14 4a1 1 0 0 1 1-1'}}, {'path': {'d': 'M15 10a1 1 0 0 1-1-1'}}, {'path': {'d': 'M21 4a1 1 0 0 0-1-1'}}, {'path': {'d': 'M21 9a1 1 0 0 1-1 1'}}, {'path': {'d': 'm3 7 3 3 3-3'}}, {'path': {'d': 'M6 10V5a2 2 0 0 1 2-2h2'}}, {'rect': {'x': '3', 'y': '14', 'width': '7', 'height': '7', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def LibraryBig(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-library-big'], 'items': [{'rect': {'width': '8', 'height': '18', 'x': '3', 'y': '3', 'rx': '1'}}, {'path': {'d': 'M7 3v18'}}, {'path': {'d': 'M20.4 18.9c.2.5-.1 1.1-.6 1.3l-1.9.7c-.5.2-1.1-.1-1.3-.6L11.1 5.1c-.2-.5.1-1.1.6-1.3l1.9-.7c.5-.2 1.1.1 1.3.6Z'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Spline(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-spline'], 'items': [{'circle': {'cx': '19', 'cy': '5', 'r': '2'}}, {'circle': {'cx': '5', 'cy': '19', 'r': '2'}}, {'path': {'d': 'M5 17A12 12 0 0 1 17 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Split(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-split'], 'items': [{'path': {'d': 'M16 3h5v5'}}, {'path': {'d': 'M8 3H3v5'}}, {'path': {'d': 'M12 22v-8.3a4 4 0 0 0-1.172-2.872L3 3'}}, {'path': {'d': 'm15 9 6-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClockAlert(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clock-alert'], 'items': [{'path': {'d': 'M12 6v6l4 2'}}, {'path': {'d': 'M20 12v5'}}, {'path': {'d': 'M20 21h.01'}}, {'path': {'d': 'M21.25 8.2A10 10 0 1 0 16 21.16'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SpellCheck2(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-spell-check-2'], 'items': [{'path': {'d': 'm6 16 6-12 6 12'}}, {'path': {'d': 'M8 12h8'}}, {'path': {'d': 'M4 21c1.1 0 1.1-1 2.3-1s1.1 1 2.3 1c1.1 0 1.1-1 2.3-1 1.1 0 1.1 1 2.3 1 1.1 0 1.1-1 2.3-1 1.1 0 1.1 1 2.3 1 1.1 0 1.1-1 2.3-1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ClockArrowDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-clock-arrow-down'], 'items': [{'path': {'d': 'M12 6v6l2 1'}}, {'path': {'d': 'M12.337 21.994a10 10 0 1 1 9.588-8.767'}}, {'path': {'d': 'm14 18 4 4 4-4'}}, {'path': {'d': 'M18 14v8'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitPullRequestDraft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-pull-request-draft'], 'items': [{'circle': {'cx': '18', 'cy': '18', 'r': '3'}}, {'circle': {'cx': '6', 'cy': '6', 'r': '3'}}, {'path': {'d': 'M18 6V5'}}, {'path': {'d': 'M18 11v-1'}}, {'line': {'x1': '6', 'x2': '6', 'y1': '9', 'y2': '21'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileDigit(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-digit'], 'items': [{'path': {'d': 'M4 12V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v12a2 2 0 0 1-2 2'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M10 16h2v6'}}, {'path': {'d': 'M10 22h4'}}, {'rect': {'x': '2', 'y': '16', 'width': '4', 'height': '6', 'rx': '2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
